
---------------------------
-- create the button
---------------------------
Glance.Functions.AddButton("Armor","LEFT")
local btn = Glance.Buttons.Armor
btn.text              = "Armor"
btn.enabled           = true
btn.events            = {"MERCHANT_SHOW","UNIT_DAMAGE","UPDATE_INVENTORY_DURABILITY"}
btn.update            = true
btn.tooltip           = true
btn.menu              = true
btn.save.perCharacter = {["autoRepair"] = true,["guildRepair"] = true}
btn.save.perAccount   = {}
btn.save.allowProfile = true

---------------------------
-- variables
---------------------------
Glance.Arrays.slotItems = {
	"HEADSLOT",
	"SHOULDERSLOT",
	"CHESTSLOT",
	"WRISTSLOT",
	"HANDSSLOT",
	"WAISTSLOT",
	"LEGSSLOT",
	"FEETSLOT",
	"MAINHANDSLOT",
	"SECONDARYHANDSLOT",
	"RANGEDSLOT",
	"BACKSLOT",
	"FINGER0SLOT",
	"FINGER1SLOT",
	"NECKSLOT",
	"TRINKET0SLOT",
	"TRINKET1SLOT",
}
Glance.Variables.party.a["Armor"] = 0
Glance.Variables.party.b["Armor"] = 0
Glance.Variables.party.c["Armor"] = 0
Glance.Variables.party.d["Armor"] = 0

---------------------------
-- special handling
---------------------------
CreateFrame("GameTooltip","Glance_Tooltip_Armor",UIParent,"GameTooltipTemplate")

---------------------------
-- update
---------------------------
function Glance.Functions.Armor.update(self, event, arg1)
	local btn = Glance.Buttons.Armor
	if btn.enabled and Glance.Variables.loaded then -- loaded keeps it from launching when defined
		Glance.Debug("function","update","Armor")
		btn.button:SetText("Armor: ".. Glance.Functions.Armor.GetDurability().."%")
		btn.button:SetWidth(btn.button:GetTextWidth())
		if event == "MERCHANT_SHOW" then
			Glance.Functions.Armor.repair()
		end
	end
end

---------------------------
-- tooltip
---------------------------
function Glance.Functions.Armor.tooltip()
	Glance.Debug("function","tooltip","Armor")
	local tooltip = Glance.Functions.Tooltip
	tooltip.Title("Armor", "GLD")
	local TotalRepairCost = Glance.Functions.Armor.checkInventory()
	if TotalRepairCost > 0 then
		tooltip.Line("The total cost to repair your armor is: "..GetCoinTextureString(TotalRepairCost,0), "WHT")
	else
		tooltip.Line("Your armor is fully repaired.", "WHT")
	end
	tooltip.Space()
	tooltip.Line("Item Level (iLvl)", "GLD")
	local itemLevel = math.floor(GetAverageItemLevel())
	local eItemLevel = 0
	for i=1,#Glance.Arrays.slotItems do
		eItemLevel = eItemLevel + Glance.Functions.Armor.GetItemLevel(Glance.Arrays.slotItems[i]);
	end
	if select(9,GetItemInfo(GetInventoryItemID("Player", GetInventorySlotInfo("MainHandSlot")))) == "INVTYPE_2HWEAPON" then
		eItemLevel = math.floor(eItemLevel/#Glance.Arrays.slotItems-1)
	else
		eItemLevel = math.floor(eItemLevel/#Glance.Arrays.slotItems)
	end
	tooltip.Double("Average Item Level",Glance.Functions.Armor.level(itemLevel), "WHT", "WHT")
	tooltip.Double("Equipped Item Level",Glance.Functions.Armor.level(eItemLevel), "WHT", "WHT")
	if ((GetNumPartyMembers() ~= 0 and sender ~= UnitName("player")) or Glance.Variables.Debug) and Glance_Local.Options.sendStats then
		Glance.Functions.addonQuery("Armor")
		local pty = Glance.Variables.party
		tooltip.Space()
		tooltip.Double("Party", "(eLVL/iLVL)/DUR", "GLD", "GLD")
		if pty.a.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.a.Armor, "WHT", "GRN")
		end
		if pty.b.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.b.Armor, "WHT", "GRN")
		end
		if pty.c.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.c.Armor, "WHT", "GRN")
		end
		if pty.d.Armor ~= 0 then
			tooltip.Double(pty.a.name, pty.d.Armor, "WHT", "GRN")
		end
	end
	tooltip.Space()
	tooltip.Line("Options", "GLD")
	if Glance.Buttons.Armor.save.perCharacter.autoRepair then
		tooltip.Double("Auto-Repair", "On", "WHT", "GRN")
	else
		tooltip.Double("Auto-Repair", "Off", "WHT", "RED")
	end
	if Glance.Buttons.Armor.save.perCharacter.guildRepair then
		if CanGuildBankRepair() then
			tooltip.Double("Use Guild Funds", "On", "WHT", "GRN")
		else
			tooltip.Double("Use Guild Funds", "On", "WHT", "GRY")
		end
	else
		tooltip.Double("Use Guild Funds", "Off", "WHT", "RED")
	end
	if CanGuildBankRepair() then
		tooltip.Double("Guild funds available today", GetCoinTextureString(GetGuildBankWithdrawMoney(),0), "WHT", "WHT")
	end
	tooltip.Space()
	tooltip.Line("Right-Click to change Options", "WHT")
end

---------------------------
-- menu
---------------------------
function Glance.Functions.Armor.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Armor")
	local HEX = Glance.Arrays.colors.HEX
	level = level or 1
	if (level == 1) then
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."Armor Options","spacer",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Auto Repair","autorepair",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Use Guild Funds","guildrepair",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "autorepair" then
			local checked, func
			if Glance.Buttons.Armor.save.perCharacter.autoRepair then checked = true else checked = false end
			func = function() Glance.Buttons.Armor.save.perCharacter.autoRepair=true; end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"On","On",level,func)
			if Glance.Buttons.Armor.save.perCharacter.autoRepair then checked = false else checked = true end
			func = function() Glance.Buttons.Armor.save.perCharacter.autoRepair=false; end;
			Glance.Functions.setInfo(nil,false,false,false,checked,"Off","Off",level,func)
		end
		if UIDROPDOWNMENU_MENU_VALUE == "guildrepair" then
			local checked, func
			if Glance.Buttons.Armor.save.perCharacter.guildRepair then checked = true else checked = false end
			func = function() Glance.Buttons.Armor.save.perCharacter.guildRepair=true; end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"On","On",level,func)
			if Glance.Buttons.Armor.save.perCharacter.guildRepair then checked = false else checked = true end
			func = function() Glance.Buttons.Armor.save.perCharacter.guildRepair=false; end;
			Glance.Functions.setInfo(nil,false,false,false,checked,"Off","Off",level,func)
		end
	end
end

---------------------------
-- messaging
---------------------------
function Glance.Functions.Armor.Message()
	local itemLevel = math.floor(GetAverageItemLevel())
	local eItemLevel = 0
	for i=1,#Glance.Arrays.slotItems do
		eItemLevel = eItemLevel + Glance.Functions.Armor.GetItemLevel(Glance.Arrays.slotItems[i]);
	end
	if select(9,GetItemInfo(GetInventoryItemID("Player", GetInventorySlotInfo("MainHandSlot")))) == "INVTYPE_2HWEAPON" then
		eItemLevel = math.floor(eItemLevel/#Glance.Arrays.slotItems-1)
	else
		eItemLevel = math.floor(eItemLevel/#Glance.Arrays.slotItems)
	end
	return "|r("..Glance.Functions.Armor.level(eItemLevel).."|r/"..Glance.Functions.Armor.level(itemLevel).."|r)/"..Glance.Functions.Armor.GetDurability().."%"
end

---------------------------
-- durability 
---------------------------
function Glance.Functions.Armor.GetDurability()
	local HEX = Glance.Arrays.colors.HEX
	local have, most, pct = 0,0,0
	local sOut
	for i = 1, 19 do
		local current, max = GetInventoryItemDurability(i)
		if current ~= nil then
			have = have + current
			most = most + max
		end
	end
	pct = math.floor((have/most) * 100)
	if pct >= 75 then
		sOut = HEX.green..pct
	elseif pct < 75 and pct > 50 then
		sOut = HEX.yellow..pct
	else
		sOut = HEX.red..pct
	end
	return sOut
end

---------------------------
-- repair costs
---------------------------
function Glance.Functions.Armor.checkInventory()
	local TotalRepairCost = 0
	for i=1, #Glance.Arrays.slotItems do
		local slotId, textureName = GetInventorySlotInfo(Glance.Arrays.slotItems[i])
		local hasItem, hasCooldown, repairCost = Glance_Tooltip_Armor:SetInventoryItem("player", slotId);
		if hasItem then
			TotalRepairCost = TotalRepairCost + (repairCost or 0)
		end
	end
	Glance_Tooltip_Armor:Hide()
	return TotalRepairCost
end

---------------------------
-- armor repair
---------------------------
function Glance.Functions.Armor.repair()
	Glance.Debug("function","repair","Armor")
	if CanMerchantRepair()==1 and Glance.Buttons.Armor.save.perCharacter.autoRepair then
		local cost, needed = GetRepairAllCost();
		if needed then
			if CanGuildBankRepair() and Glance.Buttons.Armor.save.perCharacter.guildRepair then
				local funds = GetGuildBankWithdrawMoney()
				if cost > funds then
					local funds = GetMoney()
					if cost > funds then
						Glance.Functions.sendMSG("You don't have enough money for repair!");
					else
						RepairAllItems();
						Glance.Functions.sendMSG("There was not enough money in your daily guild bank allotment for repair.  Your items have been repaired from your own funds for "..GetCoinTextureString(cost,0))
					end
				else
					RepairAllItems(1)
					Glance.Functions.sendMSG("Your items have been repaired by the guild for "..GetCoinTextureString(cost,0))
					return
				end
			else
				local funds = GetMoney()
				if cost > funds then
					Glance.Functions.sendMSG("You don't have enough money for repair!");
				else
					RepairAllItems();
					Glance.Functions.sendMSG("Your items have been repaired for "..GetCoinTextureString(cost,0))
				end
			end
		end
	end
end

---------------------------
-- item level
---------------------------
function Glance.Functions.Armor.level(itemLevel)
	local HEX = Glance.Arrays.colors.HEX
	if itemLevel < 272 then
		return HEX.gray..itemLevel
	elseif itemLevel < 305 then
		return HEX.white..itemLevel
	elseif itemLevel < 329 then
		return HEX.green..itemLevel
	elseif itemLevel < 346 then
		return HEX.blue..itemLevel
	elseif itemLevel >= 346 then
		return HEX.purple..itemLevel
	end
end

---------------------------
-- get item level
---------------------------
function Glance.Functions.Armor.GetItemLevel(slot)
	if GetInventoryItemID("Player", GetInventorySlotInfo(slot)) ~= nil then
		local _, _, _, iLevel = GetItemInfo(GetInventoryItemID("Player", GetInventorySlotInfo(slot)));
		return iLevel;
	else 
		return 0;
	end
end

---------------------------
-- load on demand
---------------------------
if Glance.Variables.loaded then
	Glance.Functions.Enable("Armor")
end