
---------------------------
-- create the button
---------------------------
Glance.Functions.AddButton("Clock","RIGHT")
local btn = Glance.Buttons.Clock
btn.text              = "Clock"
--btn.font              = "Interface\\AddOns\\Glance\\fonts\\digital-7.ttf"
btn.events            = {}
btn.update            = true
btn.tooltip           = true
btn.click             = true
btn.timer1            = true
btn.menu              = true
btn.save.perAccount   = {["DisplayClock"] = "server"}


---------------------------
-- update
---------------------------
function Glance.Functions.Clock.update()
	local btn  = Glance.Buttons.Clock
	local func = Glance.Functions.Clock
	if btn.enabled and Glance.Variables.loaded then -- loaded keeps it from launching when defined
		local hour, min = GetGameTime()
		local lhour = tonumber(date("%H"))
		if Glance.Buttons.Clock.save.perAccount.DisplayClock == "local" then
			btn.button:SetFormattedText("|r%s:%s %s (L)", func.GetHour(lhour), func.GetMin(min), func.GetAMPM(lhour))
		elseif Glance.Buttons.Clock.save.perAccount.DisplayClock == "date" then
			btn.button:SetText(date("%m/%d/%y"))
		else
			btn.button:SetFormattedText("|r%s:%s %s (S)", func.GetHour(hour), func.GetMin(min), func.GetAMPM(hour))
		end
		btn.button:SetWidth(btn.button:GetTextWidth())
	end
end

---------------------------
-- tooltip
---------------------------
function Glance.Functions.Clock.tooltip()
	Glance.Debug("function","tooltip","Clock")
	local func = Glance.Functions.Clock
	local tooltip = Glance.Functions.Tooltip
	local hour, min = GetGameTime()
	local lhour = tonumber(date("%H"))
	tooltip.Title("Clock","GLD")
	tooltip.Double("Server Time: ", func.GetHour(hour)..":"..func.GetMin(min).." "..func.GetAMPM(hour), "WHT","GRN")
	tooltip.Double("Local Time: ", func.GetHour(lhour)..":"..func.GetMin(min).." "..func.GetAMPM(lhour), "WHT","GRN")
	tooltip.Double("Date: ", date("%m/%d/%y"), "WHT","GRN")
	tooltip.Space()
	tooltip.Line("(Click to open the calendar)","WHT")
	tooltip.Line("(Right-Click to switch display)","WHT")
end

---------------------------
-- click
---------------------------
function Glance.Functions.Clock.click(self, button, down)
	Glance.Debug("function","click","Clock")
	if (button == "LeftButton") then 
		ToggleCalendar()
	end
end

---------------------------
-- menu
---------------------------
function Glance.Functions.Clock.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Clock")
	local HEX = Glance.Arrays.colors.HEX
	level = level or 1
	if (level == 1) then
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."Clock Options","spacer",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Display","display",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "display" then
			local checked, func
			if Glance.Buttons.Clock.save.perAccount.DisplayClock=="local" then checked = true else checked = false end
			func = function() Glance.Buttons.Clock.save.perAccount.DisplayClock="local"; Glance.Buttons.Clock.save.perAccount.DisplayClock="local"; Glance.Functions.Clock.update() end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"Local Time","Local Time",level,func)
			if Glance.Buttons.Clock.save.perAccount.DisplayClock=="server" then checked = true else checked = false end
			func = function() Glance.Buttons.Clock.save.perAccount.DisplayClock="server"; Glance.Buttons.Clock.save.perAccount.DisplayClock="server"; Glance.Functions.Clock.update() end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"Server Time","Server Time",level,func)
			if Glance.Buttons.Clock.save.perAccount.DisplayClock=="date" then checked = true else checked = false end
			func = function() Glance.Buttons.Clock.save.perAccount.DisplayClock="date"; Glance.Buttons.Clock.save.perAccount.DisplayClock="date"; Glance.Functions.Clock.update() end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"Date","Date",level,func)
		end
	end
end

---------------------------
-- Clock Hour function
---------------------------
function Glance.Functions.Clock.GetHour(hour)
	if hour > 12 then
		hour = hour - 12
	end
	if hour == 0 then
		hour = 12
	end
	return hour
end

---------------------------
-- Clock Hour function
---------------------------
function Glance.Functions.Clock.GetMin(min)
	if min < 10 then
		return "0"..min
	end
	return min
end

---------------------------
-- Clock DST function
---------------------------
function Glance.Functions.Clock.GetAMPM(hour)
	if hour < 12 then
		return "AM"
	else
		return "PM"
	end
end

---------------------------
-- load on demand
---------------------------
if Glance.Variables.loaded then
	Glance.Functions.Enable("Clock")
end
