
---------------------------
-- create the button
---------------------------
Glance.Functions.AddButton("DualSpec","RIGHT")
local btn = Glance.Buttons.DualSpec
btn.text              = "     "
btn.enabled           = true
btn.texture.normal    = "Interface\\AddOns\\Glance_DualSpec\\die2.tga"
btn.events            = {"CHARACTER_POINTS_CHANGED","PLAYER_TALENT_UPDATE","WEAR_EQUIPMENT_SET","EQUIPMENT_SETS_CHANGED"}
btn.update            = true
btn.tooltip           = true
btn.click             = true
btn.menu              = true
btn.timer5            = true
btn.save.perCharacter = {}
btn.save.perAccount   = {}



---------------------------
-- tooltip
---------------------------
function Glance.Functions.DualSpec.update(self, event, arg1)
	local btn = Glance.Buttons.DualSpec
	if btn.enabled and Glance.Variables.loaded then -- loaded keeps it from launching when defined
		Glance.Debug("function","update","DualSpec")
		local spec = GetActiveTalentGroup(false, false);
		local hasStance = false
		for i=1,GetNumShapeshiftForms() do
			local icon, name, checked, isCastable = GetShapeshiftFormInfo(i)
			if (checked) then hasStance = true; end
		end
		if (spec == 1) then
			if not hasStance then
				btn.button:SetNormalTexture("Interface\\AddOns\\Glance_DualSpec\\die1red.tga")
			else
				btn.button:SetNormalTexture("Interface\\AddOns\\Glance_DualSpec\\die1.tga")
			end
		else
			if not hasStance then
				btn.button:SetNormalTexture("Interface\\AddOns\\Glance_DualSpec\\die2red.tga")
			else
				btn.button:SetNormalTexture("Interface\\AddOns\\Glance_DualSpec\\die2.tga")
			end
		end
	end
end

---------------------------
-- tooltip
---------------------------
function Glance.Functions.DualSpec.tooltip()
	Glance.Debug("function","tooltip","DualSpec")
	Glance.Functions.DualSpec.update()
	local tooltip = Glance.Functions.Tooltip
	tooltip.Title("DualSpec", "GLD")
	tooltip.Double("Talent Tree: ", Glance.Functions.DualSpec.getSpec().." "..Glance.Functions.DualSpec.getBuild(GetActiveTalentGroup(false, false)), "WHT","GRN")
	for i=1,GetNumEquipmentSets() do
		local name,icon,_,checked = GetEquipmentSetInfo(i);
		if (checked) then tooltip.Double("Equipment Set:", name, "WHT", "GRN") end
	end
	local hasStance = false
	for i=1,GetNumShapeshiftForms() do
		local icon, name, checked, isCastable = GetShapeshiftFormInfo(i)
		if (checked) then tooltip.Double("Stance/Aura:", name, "WHT", "GRN"); hasStance = true; end
	end
	if not hasStance then
		tooltip.Double("Stance/Aura:", "NONE SELECTED", "WHT", "RED");
	end
	tooltip.Space()
	tooltip.Wrap("Items in the stance/presence/aura bar may be shown but not activated by Glance.", "YEL")
	tooltip.Space()
	tooltip.Line("(Left-Click to switch specs)", "WHT")
	tooltip.Line("(Right-Click to switch gear sets)", "WHT")
end

---------------------------
-- menu
---------------------------
function Glance.Functions.DualSpec.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","DualSpec")
	local HEX = Glance.Arrays.colors.HEX
	level = level or 1
	if (level == 1) then
		local checked, func
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."DualSpec: Talent Tree","spacer",level,nil)
		
		checked = Glance.Functions.DualSpec.getSpecCheck(1);
		func = function() Glance.Functions.DualSpec.setSpec() end;
		Glance.Functions.setInfo(nil,nil,false,false,checked,HEX.green.."P: "..HEX.gold..Glance.Functions.DualSpec.getBuild(1),"spec1",level,func)
		checked = Glance.Functions.DualSpec.getSpecCheck(2);
		Glance.Functions.setInfo(nil,nil,false,false,checked,HEX.red.."S: "..HEX.gold..Glance.Functions.DualSpec.getBuild(2),"spec2",level,func)
		
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.." ","spacer",level,nil)
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."DualSpec: Equipment Sets","spacer",level,nil)
		
		for i=1,GetNumEquipmentSets() do
			local name,icon,_,checked = GetEquipmentSetInfo(i);
			func = function() UseEquipmentSet(name); Glance.Functions.sendMSG("You have switched to your |cffff0000"..name.."|r Equipment Set") end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,nil,false,false,checked,HEX.gold..name,"name",level,func,icon)
		end
		
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.." ","spacer",level,nil)
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."DualSpec: Stance","spacer",level,nil)
		
		for i=1,GetNumShapeshiftForms() do
			local icon, name, checked, isCastable = GetShapeshiftFormInfo(i)
			Glance.Functions.setInfo(true,nil,false,false,checked,HEX.gold..name,"name",level,nil,icon)
		end
	end
end

---------------------------
-- messaging
---------------------------
function Glance.Functions.DualSpec.click(self, button, down)
	Glance.Debug("function","click","DualSpec")
	if button == "LeftButton" then
		Glance.Functions.DualSpec.setSpec()
		Glance.Functions.DualSpec.update()
	end
end

---------------------------
-- get talent build
---------------------------
function Glance.Functions.DualSpec.getBuild(spec)
	local _,b1,_,_,t1,_,_ = GetTalentTabInfo(1, false, false, spec);
	local _,b2,_,_,t2,_,_ = GetTalentTabInfo(2, false, false, spec);
	local _,b3,_,_,t3,_,_ = GetTalentTabInfo(3, false, false, spec);
	if ( t1 > t2 and t1 > t3 ) then
		buildTree = b1;
	elseif ( t2 > t3 ) then
		buildTree = b2;
	elseif ( t3 > 0 ) then
		buildTree = b3;
	else
		buildTree = "n/a";
	end
	return buildTree..format(" (%d/%d/%d)",t1,t2,t3);
end

---------------------------
-- get spec
---------------------------
function Glance.Functions.DualSpec.getSpec()
	local spec = GetActiveTalentGroup(false, false);
	if (spec == 1) then
		return "|cff00ff00Primary|r";
	else
		return "|cffff0000Secondary|r";
	end
end
function Glance.Functions.DualSpec.getSpecCheck(which)
	local spec = GetActiveTalentGroup(false, false);
	if (spec == which) then
		return true
	else
		return false
	end
end

---------------------------
-- set spec
---------------------------
function Glance.Functions.DualSpec.setSpec()
	local spec = GetActiveTalentGroup(false, false);
	if (spec == 1) then
		SetActiveTalentGroup(2)
		btn.button:SetNormalTexture("Interface\\AddOns\\Glance_DualSpec\\die2.tga")
		Glance.Functions.sendMSG("You have switched to your |cffff0000Secondary|r spec. "..Glance.Functions.DualSpec.getBuild(2))
	else
		SetActiveTalentGroup(1)
		btn.button:SetNormalTexture("Interface\\AddOns\\Glance_DualSpec\\die1.tga")
		Glance.Functions.sendMSG("You have switched to your |cff00ff00Primary|r spec. "..Glance.Functions.DualSpec.getBuild(1))
	end
end

---------------------------
-- load on demand
---------------------------
if Glance.Variables.loaded then
	Glance.Functions.Enable("DualSpec")
end