
---------------------------
-- create the button
---------------------------
Glance.Functions.AddButton("Gold","LEFT")
local btn = Glance.Buttons.Gold
btn.text              = "Gold"
btn.events            = {"PLAYER_MONEY"}
btn.update            = true
btn.onload            = true
btn.tooltip           = true
btn.menu              = true
btn.save.perCharacter = {["DisplayGold"]="character"}
btn.save.perAccount   = {[GetRealmName()] = { ["HordeGold"] = {},["AllianceGold"] = {} }}
btn.save.allowProfile = true


---------------------------
-- update
---------------------------
function Glance.Functions.Gold.update()
	local btn = Glance.Buttons.Gold
	if btn.enabled and Glance.Variables.loaded then -- loaded keeps it from launching when defined
		Glance.Debug("function","update","Gold")
		if Glance.Buttons.Gold.save.perCharacter.DisplayGold == "account" then
			local horde,alliance,total = btn.save.perAccount[GetRealmName()]["HordeGold"],btn.save.perAccount[GetRealmName()]["AllianceGold"],0
			for i=1,#horde do
				local name,count = unpack(horde[i])
				total = total + count
			end
			for i=1,#alliance do
				local name,count = unpack(alliance[i])
				total = total + count
			end
			btn.button:SetText(GetCoinTextureString(total,0))
		elseif Glance.Buttons.Gold.save.perCharacter.DisplayGold == "gold/hour" then
			local gti = Glance.Variables.gametime
			gti.session = time() - gti.initSession
			local gsession, gpersec, gperhour = 0,0,0
			if Glance.Variables.gold ~=0 and Glance.Variables.gold ~= nil then
				gsession = GetMoney() - Glance.Variables.gold
				gpersec = gsession/Glance.Variables.gametime.session
				gperhour = math.ceil(gpersec*3600)
				if gperhour < 0 then
					btn.button:SetText("-"..GetCoinTextureString(-gperhour,0).."/h")
				else
					btn.button:SetText(GetCoinTextureString(-gperhour,0).."/h")
				end
			else
				btn.button:SetText(GetCoinTextureString(0,0).."/h")
			end
		else
			btn.button:SetText(GetCoinTextureString(GetMoney(),0))
		end
		btn.button:SetWidth(btn.button:GetTextWidth())
		Glance.Functions.Gold.save() 
	end
end


---------------------------
-- onload
---------------------------
function Glance.Functions.Gold.onload()
	Glance.Variables.gold = GetMoney()
end


---------------------------
-- save
---------------------------
function Glance.Functions.Gold.save()
	Glance.Debug("function","save","Gold")
	local faction = Glance.Buttons.Gold.save.perAccount[GetRealmName()][select(1,UnitFactionGroup("player")).."Gold"]
	local foundPlayer = false
	if faction == nil then faction = {} end
	if faction[1] == nil then
		faction[1] = { UnitName("player"), GetMoney() }
	else
		for i=1,#faction do
			if faction[i][1] == UnitName("player") then
				faction[i] = { UnitName("player"), GetMoney() }
				foundPlayer = true
			end
		end
		if not foundPlayer then
			faction[#faction+1] = { UnitName("player"), GetMoney() }
		end
	end
end

---------------------------
-- tooltip
---------------------------
function Glance.Functions.Gold.tooltip()
	Glance.Debug("function","tooltip","Gold")
	local btn = Glance.Buttons.Gold
	local tooltip = Glance.Functions.Tooltip
	local gti = Glance.Variables.gametime
	gti.session = time() - gti.initSession
	local horde,alliance = btn.save.perAccount[GetRealmName()]["HordeGold"],btn.save.perAccount[GetRealmName()]["AllianceGold"]
	local htotal, atotal, total = 0, 0, 0
	local h,a,b = false, false, false
	tooltip.Title("Gold in Account","GLD")
	if #horde ~= 0 then h = true end
	if #alliance ~= 0 then a = true end
	if h and a then b = true end
	if b or h then
		if b then 
			tooltip.Space()
			tooltip.Line("Horde Gold","GLD") 
		end
		for i=1,#horde do
			local name,count = unpack(horde[i])
			tooltip.Double(name,GetCoinTextureString(count,0),"WHT","WHT")
			htotal = htotal + count
			total = total + count
		end
		if b then tooltip.Double("Horde Total",GetCoinTextureString(htotal,0),"GRN","WHT") end
	end
	if b or a then
		if b then 
			tooltip.Space()
			tooltip.Line("Alliance Gold","GLD")
		end
		for i=1,#alliance do
			local name,count = unpack(alliance[i])
			tooltip.Double(name,GetCoinTextureString(count,0),"WHT","WHT")
			atotal = atotal + count
			total = total + count
		end
		if b then tooltip.Double("Alliance Total",GetCoinTextureString(atotal,0),"GRN","WHT") end
	end
	tooltip.Space()
	tooltip.Double("Total Gold",GetCoinTextureString(total,0),"GRN","WHT")
	local gsession, gpersec, gperhour = 0,0,0
	if Glance.Variables.gold ~=0 then
		tooltip.Space()
		tooltip.Line("Session","GLD")
		gsession = GetMoney() - Glance.Variables.gold
		gpersec = gsession/Glance.Variables.gametime.session
		gperhour = math.ceil(gpersec*3600)
		if gsession < 0 then
			tooltip.Double("Gold This Session","-"..GetCoinTextureString(-gsession,0),"WHT","WHT")
		else
			tooltip.Double("Gold This Session",GetCoinTextureString(gsession,0),"WHT","WHT")
		end
		if gperhour < 0 then
			tooltip.Double("Gold/Hour","-"..GetCoinTextureString(-gperhour,0),"WHT","WHT")
		else
			tooltip.Double("Gold/Hour",GetCoinTextureString(gperhour,0),"WHT","WHT")
		end
		tooltip.Space()
		tooltip.Double("Display",Glance.Buttons.Gold.save.perCharacter.DisplayGold,"GLD","WHT")
		tooltip.Space()
		tooltip.Line("(Right-Click to switch display)","WHT")
	end
end


---------------------------
-- menu
---------------------------
function Glance.Functions.Gold.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Gold")
	local HEX = Glance.Arrays.colors.HEX
	level = level or 1
	if (level == 1) then
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."Gold Options","spacer",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Display","display",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "display" then
			local checked, func
			if Glance.Buttons.Gold.save.perCharacter.DisplayGold=="character" then checked = true else checked = false end
			func = function() Glance.Buttons.Gold.save.perCharacter.DisplayGold="character"; Glance.Functions.Gold.update() end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"This Character","This Character",level,func)
			if Glance.Buttons.Gold.save.perCharacter.DisplayGold=="account" then checked = true else checked = false end
			func = function() Glance.Buttons.Gold.save.perCharacter.DisplayGold="account"; Glance.Functions.Gold.update() end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"This Account","This Account",level,func)
			if Glance.Buttons.Gold.save.perCharacter.DisplayGold=="gold/hour" then checked = true else checked = false end
			func = function() Glance.Buttons.Gold.save.perCharacter.DisplayGold="gold/hour"; Glance.Functions.Gold.update() end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"Gold per Hour","Gold per Hour",level,func)
		end
	end
end

---------------------------
-- load on demand
---------------------------
if Glance.Variables.loaded then
	Glance.Functions.Enable("Gold")
end