
---------------------------
-- create the button
---------------------------
Glance.Functions.AddButton("Memory","LEFT")
local btn = Glance.Buttons.Memory
btn.text              = "Memory"
btn.events            = {"PLAYER_LOGIN"}
btn.update            = true
btn.click             = true
btn.onload            = true
btn.tooltip           = true
btn.timer5            = true
btn.timerTooltip      = true
btn.menu              = true
btn.save.perAccount = { ["collectGarbage"] = true, ["oneGlance"] = true }

---------------------------
-- variables
---------------------------
Glance.Variables.memory = 0
Glance.Variables.addons = {}
Glance.Variables.gaddons = {}

---------------------------
-- timers
---------------------------
Glance.Functions.AddTimer("Memory",0,5,true,nil,nil,nil)

---------------------------
-- update
---------------------------
function Glance.Functions.Memory.update()
	local btn  = Glance.Buttons.Memory
	if btn.enabled and Glance.Variables.loaded then -- loaded keeps it from launching when defined	
		local total = 0
		UpdateAddOnMemoryUsage()
		for i=1, GetNumAddOns() do
			if IsAddOnLoaded(i) then
				local memory = GetAddOnMemoryUsage(i)
				total = total + memory
			end
		end
		Glance.Variables.memory = total
		btn.button:SetFormattedText("Mem: "..Glance.Functions.Memory.FormatMemory(total))
		btn.button:SetWidth(btn.button:GetTextWidth())
	end
end

---------------------------
-- tooltip
---------------------------
function Glance.Functions.Memory.tooltip()
	Glance.Debug("function","tooltip","Memory")
	local func = Glance.Functions.Memory
	local tooltip = Glance.Functions.Tooltip
	Glance.Functions.Memory.update()
	local k,v,i
	local resort = false
	local acp = false
	for i=1, #Glance.Variables.addons do
		if Glance.Timers.Memory[1] <= 1 then
			local mem = GetAddOnMemoryUsage(Glance.Variables.addons[i][1])
			if Glance.Variables.addons[i][1] == "Glance" and Glance.Buttons.Memory.save.perAccount.oneGlance then
				local total = 0
				for j=1, #Glance.Variables.gaddons do
					local gmemory = GetAddOnMemoryUsage(Glance.Variables.gaddons[j][1])
					total = total + gmemory
					--print(Glance.Variables.gaddons[j][1]..": "..func.FormatMemory(gmemory).." Total: "..func.FormatMemory(total))
				end
				mem = total
			end
			if Glance.Variables.addons[i][2] ~= mem then
				if Glance.Variables.addons[i][2] > mem then
					Glance.Variables.addons[i][4] = "down"
				elseif Glance.Variables.addons[i][2] < mem then
					Glance.Variables.addons[i][4] = "up"
				end
				Glance.Variables.addons[i][3] = "GRN"
				Glance.Variables.addons[i][2] = mem
				resort = true
			else 
				Glance.Variables.addons[i][3] = "LBL"
				Glance.Variables.addons[i][4] = "steady"
			end
		else
			Glance.Variables.addons[i][3] = "LBL"
			Glance.Variables.addons[i][4] = "steady"
		end
	end
	--if Glance.Timers.Memory[1] <= 1 then
	if resort then
		table.sort(Glance.Variables.addons, function(a, b) return a[2] > b[2] end)
		resort = false
	end
	tooltip.Title("Memory Usage", "GLD")
	for k, v in pairs(Glance.Variables.addons) do
		if v[2] > 1000 then
			tooltip.Double("|T".."Interface\\Addons\\Glance_Memory\\"..v[4]..":0|t "..format("%s", v[1]), func.FormatMemory(v[2]), v[3], "RED")
		elseif v[2] > 500 then
			tooltip.Double("|T".."Interface\\Addons\\Glance_Memory\\"..v[4]..":0|t "..format("%s", v[1]), func.FormatMemory(v[2]), v[3], "YEL")
		else
			tooltip.Double("|T".."Interface\\Addons\\Glance_Memory\\"..v[4]..":0|t "..format("%s", v[1]), func.FormatMemory(v[2]), v[3], "GRN")
		end
		if v[1] == "ACP" then
			acp = true
		end
	end
	tooltip.Space()
	tooltip.Double("Total Memory Usage: ", func.FormatMemory(Glance.Variables.memory), "WHT","WHT")
	tooltip.Line(" ","WHT")
	tooltip.Line("(Left-Click to force garbage collection)","WHT")
	tooltip.Line("(Right-Click to change Options)","WHT")
	if acp then
		tooltip.Line("(Shift-Click to launch ACP)","WHT")
	end
end

---------------------------
-- click
---------------------------
function Glance.Functions.Memory.click(self, button, down)
	Glance.Debug("function","click","Memory")
	if (button == "LeftButton") then 
		if IsShiftKeyDown() then
			ShowUIPanel(ACP_AddonList)
		else
			Glance.Functions.Memory.collectGarbage()
		end
	end
end

---------------------------
-- onload
---------------------------
function Glance.Functions.Memory.onload()
	wipe(Glance.Variables.addons)
	local i = 0
	UpdateAddOnMemoryUsage()
	if Glance.Buttons.Memory.save.perAccount.oneGlance then
		local total = 0
		for i=1, GetNumAddOns() do
			local name, title = GetAddOnInfo(i)
			if Glance.Functions.matchSingle(name,"Glance") then
				local memory = GetAddOnMemoryUsage(i)
				total = total + memory
				table.insert(Glance.Variables.gaddons, {name, memory,"LBL","steady"})
			end
		end
		table.insert(Glance.Variables.addons, {GetAddOnInfo("Glance"), total,"LBL","steady"})
	end
	for i=1, GetNumAddOns() do
		if IsAddOnLoaded(i) then
			local memory = GetAddOnMemoryUsage(i)
			local name, title = GetAddOnInfo(i)
			if not Glance.Functions.matchSingle(name,"Glance") then
				table.insert(Glance.Variables.addons, {GetAddOnInfo(i), memory,"LBL","steady"})
			elseif not Glance.Buttons.Memory.save.perAccount.oneGlance then
				table.insert(Glance.Variables.addons, {GetAddOnInfo(i), memory,"LBL","steady"})
			end
		end
	end
	table.sort(Glance.Variables.addons, function(a, b) return a[2] > b[2] end)
	if Glance.Buttons.Memory.save.perAccount.collectGarbage then
		Glance.Functions.Memory.collectGarbage() 
	end
end


---------------------------
-- menu
---------------------------
function Glance.Functions.Memory.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Memory")
	local HEX = Glance.Arrays.colors.HEX
	level = level or 1
	if (level == 1) then
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."Memory Options","spacer",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Collect Garbage on Login","garbage",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Show only one entry for Glance","one",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "garbage" then
			local checked, func
			if Glance.Buttons.Memory.save.perAccount.collectGarbage then checked = true else checked = false end
			func = function() Glance.Buttons.Memory.save.perAccount.collectGarbage=true; end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"On","On",level,func)
			if Glance.Buttons.Memory.save.perAccount.collectGarbage then checked = false else checked = true end
			func = function() Glance.Buttons.Memory.save.perAccount.collectGarbage=false; end;
			Glance.Functions.setInfo(nil,false,false,false,checked,"Off","Off",level,func)
		end
		if UIDROPDOWNMENU_MENU_VALUE == "one" then
			local checked, func
			if Glance.Buttons.Memory.save.perAccount.oneGlance then checked = true else checked = false end
			func = function() Glance.Buttons.Memory.save.perAccount.oneGlance=true; Glance.Functions.Memory.onload() end;
			--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
			Glance.Functions.setInfo(nil,false,false,false,checked,"On","On",level,func)
			if Glance.Buttons.Memory.save.perAccount.oneGlance then checked = false else checked = true end
			func = function() Glance.Buttons.Memory.save.perAccount.oneGlance=false; Glance.Functions.Memory.onload() end;
			Glance.Functions.setInfo(nil,false,false,false,checked,"Off","Off",level,func)
		end
	end
end

---------------------------
-- format memory usage
---------------------------
function Glance.Functions.Memory.FormatMemory(usage)
	local HEX = Glance.Arrays.colors.HEX
	if usage > 1000 then
		return format(HEX.red.."%.2f "..HEX.white.."mb", usage/1024)
	elseif usage > 500 then
		return format(HEX.yellow.."%.2f "..HEX.white.."kb", usage)
	elseif usage > 0 then
		return format(HEX.green.."%.2f "..HEX.white.."kb", usage)
	end
end

---------------------------
-- garbage collection
---------------------------
function Glance.Functions.Memory.collectGarbage()
	local current = collectgarbage("count")
	collectgarbage("collect")
	UpdateAddOnMemoryUsage()
	local garbage = current - collectgarbage("count")
	Glance.Functions.sendMSG("Garbage Collected. ("..Glance.Functions.Memory.FormatMemory(garbage)..")");
end


---------------------------
-- load on demand
---------------------------
if Glance.Variables.loaded then
	Glance.Functions.Enable("Memory")
end