
---------------------------
-- create the button
---------------------------
Glance.Functions.AddButton("Mounts","RIGHT")
local btn = Glance.Buttons.Mounts
btn.text              = "      "
btn.enabled           = true
btn.texture.normal    = "Interface\\AddOns\\Glance_Mounts\\mount.tga"
btn.events            = {"COMPANION_LEARNED"}
btn.update            = true
btn.click             = true
btn.tooltip           = true
btn.menu              = true
btn.options           = true
btn.onload            = true
btn.save.perCharacter = {["Mounts"] = {}}
btn.save.perAccount   = {}

---------------------------
-- commands
---------------------------
Glance.Functions.AddCommand("Mounts","random","Summon a random mount",function() if IsMounted() then DismissCompanion("MOUNT") else Glance.Functions.Mounts.summonRandom() end end)
Glance.Functions.AddCommand("Mounts","random-air","Summon a random flying mount",function() if IsMounted() then DismissCompanion("MOUNT") else Glance.Functions.Mounts.summonRandomAir() end end)
Glance.Functions.AddCommand("Mounts","random-land","Summon a random ground mount",function() if IsMounted() then DismissCompanion("MOUNT") else Glance.Functions.Mounts.summonRandomLand() end end)
Glance.Functions.AddCommand("Mounts","random-water","Summon a random water mount",function() if IsMounted() then DismissCompanion("MOUNT") else Glance.Functions.Mounts.summonRandomWater() end end)

---------------------------
-- variables
---------------------------
Glance.Arrays.flightMounts = {
	"hippogryph",
	"gryphon",
	"wind",
	"ashes",
	"dragonhawk",
	"nether",
	"wyrm",
	"drake",
	"mimiron",
	"frostbrood",
	"phoenix",
	"spectral steed",
	"flying",
	"vial of the sands",
	"ebon blade",
	"celestial",
	"headless",
	"flying",
}
Glance.Arrays.specialMounts = {
	"celestial",
	"headless",
	"location",
	"extremely",
	"carpet",
	"machine",
	"rocket",
	"guardian",
	"changes",
}
Glance.Arrays.fastMounts = {
	"very",
	"skill",
	"ebon blade",
}
Glance.Arrays.waterMounts = {
	"seahorse",
	"turtle",
}
Glance.Arrays.tmpmount = {}
Glance.Arrays.mount = {}
Glance.Variables.MountScrollIDX = 0


---------------------------
-- update
---------------------------
function Glance.Functions.Mounts.update(self, event, arg1)
	if event == "COMPANION_LEARNED" then
		Glance.Functions.Mounts.resetMountList()
		Glance.Functions.createMenu("Mounts")
	end
end

---------------------------
-- tooltip
---------------------------
function Glance.Functions.Mounts.tooltip()
	Glance.Debug("function","tooltip","Mounts")
	local tooltip = Glance.Functions.Tooltip
	local HEX = Glance.Arrays.colors.HEX
	tooltip.Title("Mounts", "GLD")
	tooltip.Line("You have obtained "..HEX.green..GetNumCompanions("MOUNT")..HEX.white.." mounts.","WHT")
	tooltip.Space()
	tooltip.Wrap("(Click to summon a random mount.)","WHT")
	tooltip.Wrap("(Right-Click to show a dropdown menu of available mounts for your skill and location. Select one to mount or dismount.)","WHT")
end

---------------------------
-- click
---------------------------
function Glance.Functions.Mounts.click(self, button, down)
	Glance.Debug("function","click","Mounts")
	if button == "LeftButton" then
		if IsMounted() then
			DismissCompanion("MOUNT")
		else
			Glance.Functions.Mounts.summonRandom()
		end
	end
end

---------------------------
-- onload
---------------------------
function Glance.Functions.Mounts.onload()
	Glance.Functions.Mounts.resetMountList()
end

---------------------------
-- menu
---------------------------
function Glance.Functions.Mounts.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Mounts")
	local HEX = Glance.Arrays.colors.HEX
	level = level or 1
	if (level == 1) then
		Glance.Functions.setInfo(nil,true,false,true,nil,HEX.white.."Mounts Options","spacer",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Flying","flying",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Riding","riding",level,nil)
		Glance.Functions.setInfo(nil,nil,true,true,nil,HEX.gold.."Swimming","swimming",level,nil)
	end
	if (level == 2) then
		if UIDROPDOWNMENU_MENU_VALUE == "flying" then
			for i=1,#Glance.Arrays.mount do
				local creatureName, icon, issummoned, air, special, fast, water, enabled = unpack(Glance.Arrays.mount[i])
				if (air or special) and enabled then
					local checked, func
					checked = Glance.Functions.Mounts.isSummoned(i)
					func = function() Glance.Functions.Mounts.summon(i) end;
					--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
					Glance.Functions.setInfo(nil,false,false,false,checked,creatureName,name,level,func,icon)
				end
			end
		end
		if UIDROPDOWNMENU_MENU_VALUE == "riding" then
			for i=1,#Glance.Arrays.mount do
				local creatureName, icon, issummoned, air, special, fast, water, enabled = unpack(Glance.Arrays.mount[i])
				if (not (air or water) or special) and enabled then
					local checked, func
					checked = Glance.Functions.Mounts.isSummoned(i)
					func = function() Glance.Functions.Mounts.summon(i) end;
					--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
					Glance.Functions.setInfo(nil,false,false,false,checked,creatureName,name,level,func,icon)
				end
			end
		end
		if UIDROPDOWNMENU_MENU_VALUE == "swimming" then
			for i=1,#Glance.Arrays.mount do
				local creatureName, icon, issummoned, air, special, fast, water, enabled = unpack(Glance.Arrays.mount[i])
				if water and enabled then
					local checked, func
					checked = Glance.Functions.Mounts.isSummoned(i)
					func = function() Glance.Functions.Mounts.summon(i) end;
					--disabled,isTitle,hasArrow,notCheckable,checked,text,value,level,func
					Glance.Functions.setInfo(nil,false,false,false,checked,creatureName,name,level,func,icon)
				end
			end
		end
	end
end

---------------------------
-- options
---------------------------
function Glance.Functions.Mounts.options()
	local pIDX = Glance.Functions.createPanel("Mounts","Select which mounts you wish to be visible on the mounts menu.",function(self) Glance.Variables.overflowFix = true end)
	Glance.Variables.MountScrollIDX = Glance.Functions.createScrollBar(_G["Glance_Panel"..pIDX],18,-70,345,378,20,Glance.Arrays.mount,1,8,Glance.Functions.Mounts.setPreferredMount)
	local pIDX = Glance.Functions.createPanel("Macros","The following macros can be made to randomize your mounts.  The choice of mount is determined by your settings in the Mounts panel.",nil)
	Glance.Functions.createText(pIDX,15,-60,"/glance random","GameFontNormal","")
	Glance.Functions.createText(pIDX,15,-75,"Summons a random mount best suited for the area you are in.","GameFontHighlight","")
	Glance.Functions.createText(pIDX,15,-110,"/glance randomair","GameFontNormal","")
	Glance.Functions.createText(pIDX,15,-125,"Summons a random flying mount.","GameFontHighlight","")
	Glance.Functions.createText(pIDX,15,-160,"/glance randomland","GameFontNormal","")
	Glance.Functions.createText(pIDX,15,-175,"Summons a random land mount.","GameFontHighlight","")
	Glance.Functions.createText(pIDX,15,-210,"/glance randomwater","GameFontNormal","")
	Glance.Functions.createText(pIDX,15,-225,"Summons a random water mount.","GameFontHighlight","")
end

---------------------------
-- mount scrollbar click
---------------------------
function Glance.Functions.Mounts.setPreferredMount(line)
	local pref, name
	--for line=1,20 do
		name = _G[getglobal("Glance_SBE"..Glance.Variables.MountScrollIDX..line):GetName().."Text"]:GetText()
		pref = _G["Glance_SBE"..Glance.Variables.MountScrollIDX..line]:GetChecked()
		if pref == 1 then
			pref = true
		else
			pref = false
		end
		if name ~= nil then
			Glance.Buttons.Mounts.save.perCharacter.Mounts[name] = pref
		end
	--end
	Glance.Functions.Mounts.resetMountList()
end

---------------------------
-- is summoned
---------------------------
function Glance.Functions.Mounts.isSummoned(id)
	local creatureID, creatureName, creatureSpellID, icon, issummoned = GetCompanionInfo("MOUNT", id);
	return issummoned
end

---------------------------
-- summon
---------------------------
function Glance.Functions.Mounts.summon(id)
	local creatureID, creatureName, creatureSpellID, icon, issummoned = GetCompanionInfo("MOUNT", id);
	if issummoned then
		DismissCompanion("MOUNT")
	else
		CallCompanion("MOUNT",id)
	end
end

---------------------------
-- get mount info
---------------------------
function Glance.Functions.Mounts.mountInfo(id)
	CreateFrame("GameTooltip","Glance_Tooltip_Mount",UIParent,"GameTooltipTemplate")
	GameTooltip_SetDefaultAnchor(Glance_Tooltip_Mount, UIParent)
	local creatureID, creatureName, creatureSpellID, icon, issummoned = GetCompanionInfo("MOUNT", id);
	local special, air, fast = false, false, false
	Glance_Tooltip_Mount:SetHyperlink("spell:"..creatureSpellID)
	air = Glance.Functions.Mounts.airMounts()
	special = Glance.Functions.Mounts.specialMounts()
	water = Glance.Functions.Mounts.waterMounts()
	fast = special or Glance.Functions.Mounts.fastMounts() 
	Glance_Tooltip_Mount:Hide();
	local showMount = true
	if Glance.Buttons.Mounts.save.perCharacter.Mounts[creatureName] ~= nil then
		showMount = Glance.Buttons.Mounts.save.perCharacter.Mounts[creatureName]
	end
	return creatureName, icon, issummoned, air, special, fast, water, showMount
end

---------------------------
-- search for flying mounts
---------------------------
function Glance.Functions.Mounts.airMounts()
	local air = false
	for i=1, #Glance.Arrays.flightMounts do
		air = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.flightMounts[i])
		if air then return true end
	end
	return false
end

---------------------------
-- search for special mounts
---------------------------
function Glance.Functions.Mounts.specialMounts()
	local special = false
	for i=1, #Glance.Arrays.specialMounts do
		special = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.specialMounts[i])
		if special then return true end
	end
	return false
end

---------------------------
-- search for fastmounts
---------------------------
function Glance.Functions.Mounts.fastMounts()
	local fast = false
	for i=1, #Glance.Arrays.fastMounts do
		fast = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.fastMounts[i])
		if fast then return true end
	end
	return false
end

---------------------------
-- search for water mounts
---------------------------
function Glance.Functions.Mounts.waterMounts()
	local water = false
	for i=1, #Glance.Arrays.waterMounts do
		water = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.waterMounts[i])
		if water then return true end
	end
	return false
end

---------------------------
-- store mounts in {}
---------------------------
function Glance.Functions.Mounts.resetMountList()
	Glance.Debug("function","resetMountList",nil)
	wipe(Glance.Arrays.mount)
	local mountListChanged = false
	for i=1,GetNumCompanions("MOUNT") do
		Glance.Arrays.mount[i] = { Glance.Functions.Mounts.mountInfo(i) }
		if Glance.Buttons.Mounts.save.perCharacter.Mounts[Glance.Arrays.mount[i][1]] == nil then
			Glance.Buttons.Mounts.save.perCharacter.Mounts[Glance.Arrays.mount[i][1]] = true
			mountListChanged = true
		end
	end
	if mountListChanged then Glance.Functions.sendMSG("Your mount list has changed.  Type '/glance options' to reconfigure your preferences.") end
end

---------------------------
-- battleground status
---------------------------
function Glance.Functions.Mounts.inBattleground()
	local pvpID, localizedName, isActive, canQueue, sec, canEnter = GetWorldPVPAreaInfo(1)
	if (isActive and GetZoneText()=="Wintergrasp") then
		return true;
	end
	pvpID, localizedName, isActive, canQueue, sec, canEnter = GetWorldPVPAreaInfo(2)
	if (isActive and GetZoneText()=="Tol Barad") then
		return true;
	end
	return false;
end

---------------------------
-- summon a random mount
---------------------------
function Glance.Functions.Mounts.summonRandom()
	Glance.Debug("function","summon","Random")
	if IsOutdoors() then
		if IsSwimming() then
			if strfind(GetMapInfo(),"Vashj") then
				Glance.Functions.Mounts.summonRandomWater()
			elseif strfind(GetMapInfo(),"Thousand") then
				Glance.Functions.Mounts.summonRandomWater()
			else 
				Glance.Functions.Mounts.summonRandomWater()
			end
		else
			if (IsFlyableArea() and not Glance.Functions.Mounts.inBattleground()) then
				Glance.Functions.Mounts.summonRandomAir()
			else
				Glance.Functions.Mounts.summonRandomLand()
			end
		end
	end
end

---------------------------
-- summon a random air mount
---------------------------
function Glance.Functions.Mounts.summonRandomAir()
	local mountCount = 0
	for i=1,#Glance.Arrays.mount do
		local creatureName, icon, issummoned, air, special, fast, water, enabled = unpack(Glance.Arrays.mount[i])
		local pvpID, localizedName, isActive, canQueue, sec, canEnter = GetWorldPVPAreaInfo(1)
		Glance.Arrays.mount[i][3] = false
		if (air or special) and enabled then
			mountCount = mountCount + 1
			Glance.Arrays.tmpmount[mountCount] = i
		end
	end
	Glance.Functions.Mounts.Randomize("Air")
end

---------------------------
-- summon a random land mount
---------------------------
function Glance.Functions.Mounts.summonRandomLand()
	local mountCount = 0
	for i=1,#Glance.Arrays.mount do
		local creatureName, icon, issummoned, air, special, fast, water, enabled = unpack(Glance.Arrays.mount[i])
		Glance.Arrays.mount[i][3] = false
		if not (air or water) and enabled then
			if strfind(creatureName,"Qiraji") then
				if strfind(GetMapInfo(),"Qiraj") then
					mountCount = mountCount + 1
					Glance.Arrays.tmpmount[mountCount] = i
				end
			else
				mountCount = mountCount + 1
				Glance.Arrays.tmpmount[mountCount] = i
			end
		end
	end
	Glance.Functions.Mounts.Randomize("Land")
end

---------------------------
-- summon a random water mount
---------------------------
function Glance.Functions.Mounts.summonRandomWater()
	local mountCount = 0
	for i=1,#Glance.Arrays.mount do
		local creatureName, icon, issummoned, air, special, fast, water, enabled = unpack(Glance.Arrays.mount[i])
		Glance.Arrays.mount[i][3] = false
		if water and enabled then
			mountCount = mountCount + 1
			Glance.Arrays.tmpmount[mountCount] = i
		end
	end
	Glance.Functions.Mounts.Randomize("Water")
end

---------------------------
-- randomize
---------------------------
function Glance.Functions.Mounts.Randomize(which)
	if #Glance.Arrays.tmpmount > 0 then
		local rdm = Glance.Arrays.tmpmount[random(1,#Glance.Arrays.tmpmount)]
		Glance.Arrays.mount[rdm][3] = true
		CallCompanion("MOUNT",rdm)
		Glance.Debug("function","summon","Random"..which..": "..Glance.Arrays.mount[rdm][1])
	end
	wipe(Glance.Arrays.tmpmount)
end

---------------------------
-- load on demand
---------------------------
if Glance.Variables.loaded then
	Glance.Functions.Enable("Mounts")
end